@@ -17,8 +17,7 @@
 
 
 
-RCircos.Demo.Mouse.And.Rat<-function()
-{
+
 	#	Load RCircos package and defined parameters. 
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
@@ -48,34 +47,11 @@ RCircos.Demo.Mouse.And.Rat<-function()
 	data(RCircos.Rat.Expr.Data);
 
 
-	#	Modify the datasets and ideogram so that they have
-	#	same chromosome names. Please make sure the items
-	#	in the two lists have same order.
-	#  	__________________________________________________
-	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
-
-	cat("Combine two ideogram as one ...\n");
-
-	species.list <- c("M", "R");
-
-	cyto.list <- list(UCSC.Mouse.GRCm38.CytoBandIdeogram, 
-			UCSC.Baylor.3.4.Rat.cytoBandIdeogram);
-	RCircos.Multiple.Species.Core.Components(cyto.list, 
-			species.list, NULL, 5, 0);
-
-	data.list <- list(RCircos.Mouse.Expr.Data, 
-			RCircos.Rat.Expr.Data);
-	expr.data <- RCircos.Multiple.Species.Dataset(data.list, 
-			species.list);
-
-
 	#	Generate link data from the two datasets. These
 	#	lines are regular R script code.
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 
-	cat("Generate link data ...\n");
-
 	mouse.data <- RCircos.Mouse.Expr.Data;
 	rat.data <- RCircos.Rat.Expr.Data;
 
@@ -96,6 +72,25 @@ RCircos.Demo.Mouse.And.Rat<-function()
 
 	link.data <- data.frame(mouse.set[,1:3], rat.set[,1:3]);
 
+
+	#	Modify the datasets and ideogram so that they have
+	#	same chromosome names. Please make sure the items
+	#	in the two lists have same order.
+	#  	__________________________________________________
+	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
+
+	species.list <- c("M", "R");
+
+	cyto.list <- list(UCSC.Mouse.GRCm38.CytoBandIdeogram, 
+			UCSC.Baylor.3.4.Rat.cytoBandIdeogram);
+	RCircos.Multiple.Species.Core.Components(cyto.list, 
+			species.list, NULL, 5, 0);
+
+	data.list <- list(RCircos.Mouse.Expr.Data, 
+			RCircos.Rat.Expr.Data);
+	expr.data <- RCircos.Multiple.Species.Dataset(data.list, 
+			species.list);
+
 	link.data[,1] <- paste(species.list[1], link.data[,1], sep="");
 	link.data[,4] <- paste(species.list[2], link.data[,4], sep="");
 
@@ -105,21 +100,19 @@ RCircos.Demo.Mouse.And.Rat<-function()
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 
-	cat("Setup RCircos core components...\n");
-
 	params <- RCircos.Get.Plot.Parameters();
 	params$base.per.unit <- 30000;
-	params$heatmap.width <- 100;
 	RCircos.Reset.Plot.Parameters(params);
 
 
+
 	#	Initialize graphic device (GUI or image file)
 	#
 	#	tiff(file="RCircos.Demo.Mouse.And.Rat.tif", height=8,
 	#		width=9, unit="in", type="cairo", res=300);
 	#
 	# 	png(file="RCircos.Demo.Mouse.And.Rat.png", height=8,
-	#		width=9, unit="in", type="windows", res=300);
+	#		width=9, unit="in", type="cairo", res=300);
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 
@@ -127,8 +120,8 @@ RCircos.Demo.Mouse.And.Rat<-function()
 
 	pdf(file="RCircos.Demo.Mouse.And.Rat.pdf", height=8, width=9);
 
-	layout(matrix(data=c(1,2), nrow=1, ncol=2), 
-				widths=c(8,1), heights=8);
+	layout(matrix(data=c(1,2), nrow=1, ncol=2), widths=c(8,1), 
+					heights=8);
 	RCircos.Set.Plot.Area();
 
 
@@ -136,15 +129,16 @@ RCircos.Demo.Mouse.And.Rat<-function()
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 
-	cat("Add chromosome ideogram ... \n");
+	cat("Plot mouse and rat chromosome ideograms\n");
 	RCircos.Chromosome.Ideogram.Plot();
 
-	cat("Add heatmap ... \n");
+
+	cat("Draw heatmap\n");
 	data.col <- 5;
 	track.num <- 1;
 	RCircos.Heatmap.Plot(expr.data, data.col, track.num, "in");
 
-	cat("Add link lines ... \n");
+	cat("Draw link lines\n");
 	track.num <- 3;
 	RCircos.Link.Plot(link.data, track.num, FALSE);
 
@@ -153,8 +147,7 @@ RCircos.Demo.Mouse.And.Rat<-function()
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 
-	cat("Add title and legend ...\n");
-
+	cat("Add title and legend\n");
 	title("RCircos Demo: Mouse and Rat Gene Expression");
 	legend(0.6, 2, legend=c("Right: GSE42081 Mouse", 
 			"Left:  GSE42081 Rat"), cex=0.8);
@@ -164,17 +157,9 @@ RCircos.Demo.Mouse.And.Rat<-function()
 	#  	__________________________________________________
 	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 
-	cat("Add color key ...\n");
+	cat("Add color key\n");  		
 
-	RedRamp <- rgb( seq(1, 1, length=256),  		
-			seq(0, 1, length=256),  		
-			seq(0, 1, length=256)) ; 		
-
-	BlueRamp <- rgb(seq(0, 1, length=256),  		
-			seq(0, 1, length=256),  		
-			seq(1, 1, length=256));  		
-
-	ColorRamp   <- cbind(BlueRamp, rev(RedRamp));
+	ColorRamp <- RCircos.Get.Heatmap.ColorScales("BlueWhiteRed");
 	ColorLevels <- seq(min(expr.data$Expr.Mean), 
 				max(expr.data$Expr.Mean), 
 				length=length(ColorRamp));
@@ -194,7 +179,3 @@ RCircos.Demo.Mouse.And.Rat<-function()
 	cat("R Circos Demo with mouse and Rat data done ...\n\n");
 
 	rm(list=ls(all=T));
-}
-
-
-RCircos.Demo.Mouse.And.Rat();
\ No newline at end of file
